@@ -3,7 +3,7 @@ import matplotlib.pyplot as plt
 import numpy as np
 
 from ...distplot import plot_dist
-from ...plot_utils import _scale_fig_size, make_label
+from ...plot_utils import _scale_fig_size
 from . import backend_kwarg_defaults, backend_show
 
 
@@ -16,6 +16,7 @@ def plot_dist_comparison(
     legend,
     groups,
     textsize,
+    labeller,
     prior_kwargs,
     posterior_kwargs,
     observed_kwargs,
@@ -47,22 +48,22 @@ def plot_dist_comparison(
 
     backend_kwargs.setdefault("figsize", figsize)
 
-    posterior_kwargs.setdefault("plot_kwargs", dict())
+    posterior_kwargs.setdefault("plot_kwargs", {})
     posterior_kwargs["plot_kwargs"]["color"] = posterior_kwargs["plot_kwargs"].get("color", "C0")
     posterior_kwargs["plot_kwargs"].setdefault("linewidth", linewidth)
-    posterior_kwargs.setdefault("hist_kwargs", dict())
+    posterior_kwargs.setdefault("hist_kwargs", {})
     posterior_kwargs["hist_kwargs"].setdefault("alpha", 0.5)
 
-    prior_kwargs.setdefault("plot_kwargs", dict())
+    prior_kwargs.setdefault("plot_kwargs", {})
     prior_kwargs["plot_kwargs"]["color"] = prior_kwargs["plot_kwargs"].get("color", "C1")
     prior_kwargs["plot_kwargs"].setdefault("linewidth", linewidth)
-    prior_kwargs.setdefault("hist_kwargs", dict())
+    prior_kwargs.setdefault("hist_kwargs", {})
     prior_kwargs["hist_kwargs"].setdefault("alpha", 0.5)
 
-    observed_kwargs.setdefault("plot_kwargs", dict())
+    observed_kwargs.setdefault("plot_kwargs", {})
     observed_kwargs["plot_kwargs"]["color"] = observed_kwargs["plot_kwargs"].get("color", "C2")
     observed_kwargs["plot_kwargs"].setdefault("linewidth", linewidth)
-    observed_kwargs.setdefault("hist_kwargs", dict())
+    observed_kwargs.setdefault("hist_kwargs", {})
     observed_kwargs["hist_kwargs"].setdefault("alpha", 0.5)
 
     if ax is None:
@@ -78,9 +79,8 @@ def plot_dist_comparison(
         axes = ax
         if ax.shape != (nvars, ngroups + 1):
             raise ValueError(
-                "Found {} shape of axes, which is not equal to data shape {}.".format(
-                    axes.shape, (nvars, ngroups + 1)
-                )
+                f"Found {axes.shape} shape of axes, "
+                f"which is not equal to data shape {(nvars, ngroups + 1)}."
             )
 
     for idx, plotter in enumerate(dc_plotters):
@@ -93,12 +93,12 @@ def plot_dist_comparison(
             else observed_kwargs
         )
         for idx2, (
-            var,
-            selection,
+            var_name,
+            sel,
+            isel,
             data,
         ) in enumerate(plotter):
-            label = make_label(var, selection)
-            label = f"{group} {label}"
+            label = f"{group}"
             plot_dist(
                 data,
                 label=label if legend else None,
@@ -111,6 +111,8 @@ def plot_dist_comparison(
                 ax=axes[idx2, -1],
                 **kwargs,
             )
+            if idx == 0:
+                axes[idx2, -1].set_xlabel(labeller.make_label_vert(var_name, sel, isel))
 
     if backend_show(show):
         plt.show()
