@@ -296,9 +296,7 @@ def get_plotting_function(plot_name, plot_module, backend):
         backend = _backend[backend]
     except KeyError as err:
         raise KeyError(
-            "Backend {} is not implemented. Try backend in {}".format(
-                backend, set(_backend.values())
-            )
+            f"Backend {backend} is not implemented. Try backend in {set(_backend.values())}"
         ) from err
 
     if backend == "bokeh":
@@ -309,7 +307,7 @@ def get_plotting_function(plot_name, plot_module, backend):
 
         except (ImportError, AssertionError) as err:
             raise ImportError(
-                "'bokeh' backend needs Bokeh (1.4.0+) installed." " Please upgrade or install"
+                "'bokeh' backend needs Bokeh (1.4.0+) installed. Please upgrade or install"
             ) from err
 
     # Perform import of plotting method
@@ -353,32 +351,21 @@ def calculate_point_estimate(point_estimate, values, bw="default", circular=Fals
         point_estimate = rcParams["plot.point_estimate"]
     elif point_estimate not in ("mean", "median", "mode", None):
         raise ValueError(
-            "Point estimate should be 'mean', 'median', 'mode' or None, not {}".format(
-                point_estimate
-            )
+            f"Point estimate should be 'mean', 'median', 'mode' or None, not {point_estimate}"
         )
     if point_estimate == "mean":
-        if skipna:
-            point_value = np.nanmean(values)
-        else:
-            point_value = np.mean(values)
+        point_value = np.nanmean(values) if skipna else np.mean(values)
     elif point_estimate == "mode":
         if values.dtype.kind == "f":
             if bw == "default":
-                if circular:
-                    bw = "taylor"
-                else:
-                    bw = "experimental"
+                bw = "taylor" if circular else "experimental"
             x, density = kde(values, circular=circular, bw=bw)
             point_value = x[np.argmax(density)]
         else:
-            point_value = mode(values)[0][0]
+            point_value = int(mode(values).mode)
     elif point_estimate == "median":
-        if skipna:
-            point_value = np.nanmedian(values)
-        else:
-            point_value = np.median(values)
 
+        point_value = np.nanmedian(values) if skipna else np.median(values)
     return point_value
 
 
@@ -609,6 +596,4 @@ def _init_kwargs_dict(kwargs):
     kwargs : dict or None
         kwargs dict to initialize
     """
-    if kwargs is None:
-        return {}
-    return kwargs.copy()
+    return {} if kwargs is None else kwargs.copy()
